OudsThemeConfigModel constructor

const OudsThemeConfigModel({
  1. OudsButtonConfig? button,
  2. @Deprecated('OudsTagConfig is deprecated and will be removed in a future version. Please migrate off of its usage.') OudsTagConfig? tag,
  3. OudsTextInputConfig? textInput,
  4. OudsAlertMessageConfig? alertMessage,
  5. required Widget child,
  6. Key? key,
})

Implementation

const OudsThemeConfigModel({
  this.button,
  @Deprecated(
    'OudsTagConfig is deprecated and will be removed in a future version. Please migrate off of its usage.',
  )
  this.tag,
  this.textInput,
  this.alertMessage,
  required super.child,
  super.key,
});