OudsComponentVersion class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- alertMessage → const String
- badge → const String
- bar → const String
- bottomSheet → const String
- bulletList → const String
- checkbox → const String
- chip → const String
- divider → const String
- inlineAlert → const String
- link → const String
- passwordInput → const String
- phoneNumberInput → const String
- pinCodeInput → const String
- radioButton → const String
- skeleton → const String
- switchButton → const String
- tag → const String
- textInput → const String