OudsTokensVersion class

Constructors

OudsTokensVersion()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

androidCore → const String
androidSystem → const String
orangeBrand → const String
orangeCompactBrand → const String
orangeCore → const String
oudsCore → const String
soshBrand → const String
soshCore → const String
wireframeBrand → const String
wireframeCore → const String