OudsSizeScheme class

Responsive size token scheme for OUDS Flutter.

Provides dynamic access to all size tokens depending on the current window width size class (mobile/tablet). Use OudsSizeScheme.fromContext to get an instance, then access any spacing token with the correct value for the device size.

Example:

final sizeScheme = OudsSizeScheme.fromContext(context: context, sizeTokens: OudsTheme.of(context).sizeTokens);
final padding = sizeScheme.scaledMedium;

Constructors

OudsSizeScheme.fromContext({required BuildContext context, required OudsSizeSemanticTokens sizeTokens})
Factory to create a responsive OudsSizeScheme from context and size tokens.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
iconDecorativeExtraExtraLarge double
no setter
iconDecorativeExtraExtraSmall double
Non-responsive tokens (direct mapping) iconDecorative
no setter
iconDecorativeExtraLarge double
no setter
iconDecorativeExtraSmall double
no setter
iconDecorativeLarge double
no setter
iconDecorativeMedium double
no setter
iconDecorativeSmall double
no setter
iconWithBodyLargeSizeLarge double
no setter
iconWithBodyLargeSizeMedium double
no setter
iconWithBodyLargeSizeSmall double
IconWithBodyLarge
no setter
iconWithBodyMediumSizeLarge double
no setter
iconWithBodyMediumSizeMedium double
no setter
iconWithBodyMediumSizeSmall double
IconWithBodyMedium
no setter
iconWithBodySmallSizeLarge double
no setter
iconWithBodySmallSizeMedium double
no setter
iconWithBodySmallSizeSmall double
Responsive size tokens (mobile/tablet) IconWithBodySmall
no setter
iconWithHeadingExtraLargeSizeLarge double
no setter
iconWithHeadingExtraLargeSizeMedium double
no setter
iconWithHeadingExtraLargeSizeSmall double
IconWithHeadingExtraLarge
no setter
iconWithHeadingLargeSizeLarge double
no setter
iconWithHeadingLargeSizeMedium double
no setter
iconWithHeadingLargeSizeSmall double
IconWithHeadingLarge
no setter
iconWithHeadingMediumSizeLarge double
no setter
iconWithHeadingMediumSizeMedium double
no setter
iconWithHeadingMediumSizeSmall double
IconWithHeadingMedium
no setter
iconWithHeadingSmallSizeLarge double
no setter
iconWithHeadingSmallSizeMedium double
no setter
iconWithHeadingSmallSizeSmall double
IconWithHeadingSmall
no setter
iconWithLabelExtraLargeSizeLarge double
no setter
iconWithLabelExtraLargeSizeMedium double
no setter
iconWithLabelExtraLargeSizeSmall double
iconWithLabelExtraSmall
no setter
iconWithLabelLargeSizeExtraLarge double
no setter
iconWithLabelLargeSizeExtraSmall double
iconWithLabelLarge
no setter
iconWithLabelLargeSizeLarge double
no setter
iconWithLabelLargeSizeMedium double
no setter
iconWithLabelLargeSizeSmall double
no setter
iconWithLabelMediumSizeExtraSmall double
iconWithLabelMedium
no setter
iconWithLabelMediumSizeLarge double
no setter
iconWithLabelMediumSizeMedium double
no setter
iconWithLabelMediumSizeSmall double
no setter
iconWithLabelSmallSizeExtraSmall double
iconWithLabelSmall
no setter
iconWithLabelSmallSizeLarge double
no setter
iconWithLabelSmallSizeMedium double
no setter
iconWithLabelSmallSizeSmall double
no setter
maxWidthTypeBodyLarge double
no setter
maxWidthTypeBodyMedium double
no setter
maxWidthTypeBodySmall double
MaxWidthTypeBody
no setter
maxWidthTypeDisplayLarge double
no setter
maxWidthTypeDisplayMedium double
no setter
maxWidthTypeDisplaySmall double
MaxWidthTypeDisplay
no setter
maxWidthTypeHeadingExtraLarge double
no setter
maxWidthTypeHeadingLarge double
no setter
maxWidthTypeHeadingMedium double
no setter
maxWidthTypeHeadingSmall double
MaxWidthTypeHeading
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeClass OudsWindowWidthSizeClass
The current window width size class.
final
sizeTokens OudsSizeSemanticTokens
The underlying semantic size tokens.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited