OudsThemeConfigModel constructor
const
OudsThemeConfigModel({
- OudsButtonConfig? button,
- @Deprecated('OudsTagConfig is deprecated and will be removed in a future version. Please migrate off of its usage.') OudsTagConfig? tag,
- OudsTextInputConfig? textInput,
- OudsAlertMessageConfig? alertMessage,
- required Widget child,
- Key? key,
Implementation
const OudsThemeConfigModel({
this.button,
@Deprecated(
'OudsTagConfig is deprecated and will be removed in a future version. Please migrate off of its usage.',
)
this.tag,
this.textInput,
this.alertMessage,
required super.child,
super.key,
});